module.exports = defineTest({
	description: 'handles errors in switch statements'
});
